@@ -27,7 +27,7 @@
 #include "kmahjongg.h"
 #include "version.h"
 
-static const char description[] = I18N_NOOP("Mahjongg Solitaire for KDE");
+static const char description[] = I18N_NOOP("Mahjongg Solitaire by KDE");
 
 int main(int argc, char ** argv)
 {
@@ -51,8 +51,6 @@ int main(int argc, char ** argv)
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
